
# Knitting Technique Notes

## Right side vs. wrong side

[How to tell the right side from the wrong side \[NimbleNeedles\]](https://nimble-needles.com/tutorials/right-side-vs-wrong-side-in-knitting/)

- "Wrong side" refers to the side of a project that **won't be visible** to the naked eye when finished.
- Typically, tails are hidden on the wrong side
- Stockinette stitch: side with little V's is the right side
- **If your cast on tail is dangling down on the right, you are on the right side.**
- **Most patterns start on the right side.** This means that every odd-numbered row you knit is the right side.

[Avoiding Bumps on the Cast-On Edge \[edieeckman.com\]](https://www.edieeckman.com/2018/12/04/avoid-bumps-cast-on/)

- When you cast on stitches using long-tail cast on, you are looking at the right side (RS) of the cast on.
- **When you turn the needle to put it in your left hand in preparation to work the first row, the purl side (wrong side, WS) is facing you** (note the bumps).
- This is why you should purl the first row after ltca when doing stockinette stitch, because the cast on row is essentially "knitted on".

## Knitting neat edges

[How to knit neat edges - The 10 best edge stitches in knitting \[NimbleNeedles\]](https://www.youtube.com/watch?v=rAd16HjsH3Y)

"selvage": edge formed by changing stitch pattern at beginning/end of every row

Three common problems that make edges look weird/irregular:

- Stretching out the first stitch of a row too much
- Stretching out the last stitch of a row too much
- Pulling the edge stitches too tight

How to mitigate these:

- First stitch: don't stretch out the loop, push stitch through loop (guide w/ right index) rather than pull
- Last stitch: don't stretch out the loop, bring needles very close together, knit close to the tips, be gentle

Edge stitches will always look different from other stitches, since they are connected to the stitch a row below on the edge side (while normal stitches are connected to adjacent stitches on the same row on both sides)

10 most common selvage stitches:

1. Chain stitch (Kettrand)
    - Easiest/most common variant
    - Comes in a bunch of variations (German, English, French)
    - Usually not suitable for picking up stitches
    - Instructions: sl1pwyif first stitch, purl last stitch
2. Garter stitch
    - Good choice for slightly firmer edge
    - Very versatile and easy to remember
    - Instructions: knit first and last stitch of every row
    - For even firmer edge: ktbl, ..., ktbl
3. Twisted slip/chain stitch
    - Variation of chain stitch w/ slightly firmer edge
    - Instructions: sl1kwyif first stitch, knit last stitch
4. Double/triple garter stitch
    - Like regular garter, but two or three knits and beginning and end of row
    - Creates flat, reversible, wide decorative border
    - Good for flattening stockinette
5. Double seed stitch
    - Alternative look for double garter (very similar behavior)
    - Instructions: k1, p1,..., p1, k1
    - Can multiply the repeat for wider edge\
    - Not suitable for seaming/picking up stitches
6. Double twisted stitch
    - Creates very tight edge
    - Difficult to pick up stitches, hard to knit uniformly on both sides
7. Double stockinette stitch
8. I-cord edge
9. Brioche/Russian edge
10. Stockinette stitch edge/seam edge

## Joining yarn

[How to join yarn in knitting - 10 techniques from easy to invisible \[NimbleNeedles\]](https://www.youtube.com/watch?v=xuu_lpzq3rI)

1. Easiest method: just tie a knot
    - only do this at the end of a row
    - leave a little tail of the new yarn and simply start knitting into it
    - at the end of the row, tie a loose knot and leave it there
    - once finished  knitting, untie the knot and weave in both ends
2. Wet/felted splice
    - works anywhere in the knitting, not just at the edges
    - pick apart ends (unraveling, fanning out)
    - wet edges, stack edges on top of each other
    - twist edges together, rub together using palms
    - pro tip: thin out ends a little before joining (cutting some strands), so join doesn't become thicker than single yarn
    - limitations: only works w/ feltable fibers (animal fibers, except silk), not suitable for color changes
    - non-feltable fibers: superwash/acrylic/cotton etc.
3. Overlap & knit double join
    - quite noticeable, especially w/ heavier yarn
    - great for fuzzy yarn that felts well, like mohair
4. Weave in as you go
    - similar to overlap & knit
    - invisible on right side, relaitvely noticeable on wrong side
5. Twist & weave
    - a bit more complicated
    - very versatile: works with every fiber, color changes etc.
    - neatest way for colorwork and round knitting
6. Weave in & twist
    - variation on twist & weave, more suited for intarsia
7. Russian join
    - sharp tapestry needle needed (as small as possible)
    - thread in yarn, then pierce right through yarn
    - push in for a 2-3 inches
    - pull through, resulting in a loop
    - pick up yarn to be joined, pu
    - works better w/ fuzzy yarns, not so well for cotton
    - creates slightly thicker section in work
8. Magic/fisherman's knot
    - basically - two overhand knotss close to each other
    - then pull ends together and trim away tails
    - leaves behind visible knot
    - not reliable for superwash
9. Back to back join
    - another technique that doesn't produce ends that need to be weaved in, but viable for colorwork
    - perfect for mid-row joins (for example, when doing scrap socks)
10. Alternating stitches
    - same as fair isle technique
    - useful for creating transitions between non-uniform (hand-dyed, novelty,...) yarns (makes border less obvious)

## Weaving in ends

[How to weave in ends in knitting - 10 different techniques \[NimbleNeedles\]](https://www.youtube.com/watch?v=aa59mMrgmCQ)

1. Knit in the tail
2. Hide the tail in the seams
3. Join a new yarn with the felting method
4. Weave in on the fly
5. Weaving in stockinette stitch ends
6. Weaving in ends in ribbing
7. Weaving in ends in Garter stitch
8. Weaving in ends when knitting colorwork
9. How to weave in ends on lace
10. Weave in cotton ends

## Reading knitting charts

[How to read a knitting chart for beginners - step by step \[NimbleNeedles\]](https://www.youtube.com/watch?v=eHdsB3PjeZs)

purls wear turtlenecks, knits wear v-necks

## Troubleshooting tension problems

[Troubleshooting Knitting Problems \[Roxanne Richardson\]](https://www.youtube.com/watch?v=0i188VMXK-c)

- Big/loose end stitches (first couple of stitches in a row)
  - Rather than trying to tighten everything up right away, knit first two stitches as normal, enter third stitch with right needle and give the working yarn a tug (tightens first two stitches)
  - By pulling/tugging out the slack on the working yarn, the _previous_ stitch is tightened, so pull _after_ the stitch is completed
  - A common, more severe problem is the tendency to **pull apart** the needles
    - This includes working too far below the tips of the needle, leading to you pulling the stitch off the needle instead of pushing it off with the right hand (and pushing up the remaining loops on the left needle to the edge in the same motion)
    - Work close to the tips!
  - Pulling on the big loop at the end of a row doesn't tighten the loop and only tightens the loops on the needle unecessarily
- Big loop on the first row after long-tail cast on
  - Again, pulling needles apart
