// knit pattern generation

// generating 4 patterns each of the following categories:
// - enumerations
// - maximally even subdivisions
// - sieves

// first, some helper functions
// these convert between different "rhythmic" representations (useful for maxeven/sieve conversion)
// example
// binary   rep: [ 1, 0, 1, 0, 0, 1, 0, 0, 1 ]
// index    rep: [ 0, 2, 5, 8 ]
// duration rep: [ 2, 3, 3, 1 ]
(
~binaryArrToDur = { |arr|
	var newArr = arr.indicesOfEqual(1).replace(0, arr.size);
	newArr.rotate(-1).differentiate
};
~binaryArrToDur.([1, 0, 1, 0, 0, 1, 0, 0, 1]).postln;

~binaryArrToIndex = { |arr|
	var newArr = arr.indicesOfEqual(1);
	newArr
};
~binaryArrToIndex.([1, 0, 1, 0, 0, 1, 0, 0, 1]).postln;

~indexArrToBinary = { |arr|
	var newSize = arr.maxItem + 1;
	var newArr = Array.fill(newSize, 0);
	newArr.put(arr, 1)
};
~indexArrToBinary.([0, 2, 5, 8]).postln;

~durArrToIndex = { |arr|
	arr.integrate.rotate(1).put(0,0)
};
~durArrToIndex.([2, 3, 3, 1]).postln;

~durArrToBinary = { |arr|
	~indexArrToBinary.(~durArrToIndex.(arr))
};
~durArrToBinary.([2,3,3,1]).postln;
)


// proceeding to the actual pattern generation

////////////////////////////////////////////////////////////////////////////////
// enumerations
// there are eight unique patterns of length four (up to inversion)
// let's generate them:
(
var n = 4;
var rangeEnd = (2**n - 1).asInteger;
var enum;

enum = (0..rangeEnd).collect(_.asBinaryDigits(n)).keep((2**(n-1)).asInteger);
enum.size.postln;
Char.nl.post;

enum.do { |pat|
	pat.clump(2).printAll;
	Char.nl.post;
};
)

////////////////////////////////////////////////////////////////////////////////
// maximally even subdivisions
// simple method to generate them (as shown by msp in mus270c.17s, lecture 2a)
(
var ratio = 7/3;
var arr;
arr = (0..3) * ratio;
arr = arr.trunc.asInteger;
arr.postln;
~indexArrToBinary.(arr)
)

// easier: use Bjorklund quark
// here's an explanation of why ~binaryArrToDur works:
b = Bjorklund(3, 8)     // [1, 0, 0, 1, 0, 0, 1, 0]
b = b.indicesOfEqual(1) // [0, 3, 6]
b = b.replace(0, 8)     // [8, 3, 6]
b = b.rotate(-1)        // [3, 6, 8]
b = b.differentiate     // [3, 3, 2]

// which lengths to try?
// multiples of 6
// multiples of 8
// multiples of 12

// let's generate all maxeven subdivs of length 16 bitstring
// interesting ones:
// k=9, n=16
(
var bjorkN = 16;
var repeats = 1;

var clumpSize = bjorkN.div(4);

var bjorks = (1..(bjorkN-1)).collect { |i| Bjorklund(i, bjorkN)};
bjorks.do { |pat|
	pat.clump(clumpSize).stutter(repeats).flat.clump(clumpSize * repeats).printAll;
	Char.nl.post;
};
)

// maxeven subdivs of length 36
// k=9, n=16
(
var bjorkN = 36;
var repeats = 4;

var clumpSize = bjorkN.div(6);

var bjorks = (1..(bjorkN-1)).collect { |i| Bjorklund(i, bjorkN)};
bjorks.do { |pat|
	pat.clump(clumpSize).stutter(repeats).flat.clump(clumpSize * repeats).printAll;
	Char.nl.post;
};
)

// maxeven subdivs of length 96
// k=43, n=96
(
var bjorkN = 96;
var repeats = 1;

var clumpSize = bjorkN.div(12);

var bjorks = (1..(bjorkN-1)).collect { |i| Bjorklund(i, bjorkN)};
bjorks.do { |pat|
	pat.clump(clumpSize).stutter(repeats).flat.clump(clumpSize * repeats).printAll;
	Char.nl.post;
};
)

// maxeven subdivs of length 56
//
(
var bjorkN = 56;
var repeats = 3;

var clumpSize = bjorkN.div(7);

var bjorks = (1..(bjorkN-1)).collect { |i| Bjorklund(i, bjorkN)};
bjorks.do { |pat|
	pat.clump(clumpSize).stutter(repeats).flat.clump(clumpSize * repeats).printAll;
	Char.nl.post;
};
)
